# Copyright 2022 Parallel Software and Systems Group, University of Maryland.
# See the top-level LICENSE file for details.
#
# SPDX-License-Identifier: MIT


from setuptools import setup

setup(
    name="pipit",
    version="0.0.1",
    description="A Python library for analyzing parallel execution traces",
    url="https://github.com/hpcgroup/pipit",
    author="Abhinav Bhatele",
    author_email="bhatele@cs.umd.edu",
    classifiers=["Development Status :: 2 - Pre-Alpha"],
    keywords="distributed computing, parallel computing",
    packages=[],
)
